@@ -15,13 +15,13 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
     $VERSION = eval $VERSION;
 
 ## Load our modules
@@ -129,7 +129,7 @@ use constant {
     ARGUMENTS        => 1,
     UNIX_EPOCH       => 2208988800,
     MIN_UDP_PORT     => 1,
-    MAX_UDP_PORT     => 65535,
+    MAX_UDP_PORT     => 65536,
     DEFAULT_NTP_PORT => 123,
 };
 
@@ -186,12 +186,12 @@ sub getSNTPTime {
 
     my $verify_port = sub {
 	my $port = shift;
-	if ( defined $port && $port =~ /^[+-]?(?=\.?\d)\d*\.?\d*(?:e[+-]?\d+)?\z/i ) {
-	    if ( $port <= MIN_UDP_PORT || $port >= MAX_UDP_PORT ) {
-		return TRUE;
+	if ( defined $port && $port =~ /^[0-9]+$/ ) {
+	    if ( $port >= MIN_UDP_PORT && MAX_UDP_PORT >= $port ) {
+		return FALSE;
 	    }
 	}
-	return FALSE;
+	return TRUE;
     };
     
     my $dot = ".";
@@ -413,6 +413,10 @@ We use the L<Data::Dumper|http://search.cpan.org/~ilyam/Data-Dumper-2.121/Dumper
   print Dumper $hashRefOutput;
   print "Error: $error\n" if ($error);
 
+DEPENDENCIES
+
+The module is implemented using IO::Socket::INET and Time::HiRes
+ and requires both these modules to be installed.
 
 =head1 AUTHOR
 
@@ -520,7 +524,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 6.0  2015/07/11 5:43:31  Thanos
+Revision 7.0  2015/07/13 1:18:31 am  Thanos
 
 
 =cut
